@@ -276,6 +276,16 @@ namespace apg {
                     }
                 }
             }
+
+            for (auto it = components.begin(); it != components.end(); ++it) {
+                if ((*it) == "PATHOLOGICAL") {
+                    // invalid separation
+                    std::vector<std::string> newcomps;
+                    newcomps.push_back(pat.apgcode());
+                    return newcomps;
+                }
+            }
+
             return components;
         }
 
