@@ -240,16 +240,30 @@ extern "C"
         s.copy(buffer, 2048);
     }
 
-    void GetWechslerOfPattern(void* pat, char* buffer) {
+    void GetWechslerOfPattern(void* pat, char* buffer, int buflen) {
         auto ppat = reinterpret_cast<apg::pattern*>(pat);
         std::string s = ppat->phase_wechsler(999999999);
-        s.copy(buffer, 2048);
+
+        if (s.length() >= buflen) {
+            std::ostringstream ss;
+            ss << "!" << (((s.length() >> 8) + 1) << 8);
+            s = ss.str();
+        }
+
+        s.copy(buffer, buflen);
     }
 
-    void GetApgcodeOfPattern(void* pat, char* buffer) {
+    void GetApgcodeOfPattern(void* pat, char* buffer, int buflen) {
         auto ppat = reinterpret_cast<apg::pattern*>(pat);
         std::string s = ppat->apgcode(999999999, 999999999);
-        s.copy(buffer, 2048);
+
+        if (s.length() >= buflen) {
+            std::ostringstream ss;
+            ss << "!" << (((s.length() >> 8) + 1) << 8);
+            s = ss.str();
+        }
+
+        s.copy(buffer, buflen);
     }
 
     void GetCompiledVersion(char* buffer) {
