@@ -391,9 +391,13 @@ class Pattern(object):
 
         return self.lifelib('GetRuleOfPattern', self.ptr, [2048])
 
-    def phase_wechsler(self):
+    def phase_wechsler(self, fn='GetWechslerOfPattern'):
 
-        return self.lifelib('GetWechslerOfPattern', self.ptr, [2048])
+        x = self.lifelib(fn, self.ptr, [2048], 2048)
+        if x.startswith('!'):
+            buflen = int(x[1:])
+            x = self.lifelib(fn, self.ptr, [buflen], buflen)
+        return x
 
     def oscar(self, maxexp=24, eventual_oscillator=True, verbose=True, return_apgcode=False):
 
@@ -409,7 +413,7 @@ class Pattern(object):
             y = x.pdetect_or_advance(exponent)
             if isinstance(y, dict):
                 if (return_apgcode):
-                    y['apgcode'] = self.lifelib('GetApgcodeOfPattern', x.ptr, [2048])
+                    y['apgcode'] = x.phase_wechsler('GetApgcodeOfPattern')
                 return y
             if (eventual_oscillator):
                 x = y
