@@ -13,7 +13,7 @@ class TestCygwin(unittest.TestCase):
     def test_numpy(self):
 
         from lifelib import autocompile
-        autocompile.verify_installation()
+        np_version = autocompile.verify_installation()
 
 if __name__ == '__main__':
     unittest.main()
